<template>
	<div class="system-user-container">
		<el-card shadow="hover">
			<div class="system-user-search mb15">
				<el-input size="default" v-model="listQuery.searchParams.accidentName" placeholder="事故名称" style="max-width: 215px" />
				<el-button size="default" type="primary" class="ml10" @click="listApi"> 查询 </el-button>
				<el-button size="default" class="ml10" @click="submitReset"> 重置 </el-button>
			</div>
			<div class="button_Line">
				<div class="button_Left">
					<el-button size="default" type="primary" @click="onOpenAdd">
						<el-icon> <Plus /> </el-icon>新建
					</el-button>
					<el-button size="default" type="warning" plain :disabled="warning" @click="onEdit('修改', deletAll[0])">
						<el-icon> <Edit /> </el-icon>修改
					</el-button>
					<el-button size="default" type="danger" @click="onDeleteAll" plain :disabled="danger">
						<el-icon> <Delete /> </el-icon>删除
					</el-button>
				</div>
				<div class="button_Right">
					<!-- <el-button @click="upButton">
						<el-icon>
							<Upload />
						</el-icon>
					</el-button>
					<el-button>
						<el-icon>
							<Download />
						</el-icon>
					</el-button>
					<el-button>
						<el-icon>
							<Refresh />
						</el-icon>
					</el-button> -->
				</div>
			</div>
			<el-table :data="tableData" style="width: 100%" ref="multipleTableRef" @selection-change="handleSelectionChange">
				<el-table-column align="center" type="selection" width="55" />
				<el-table-column align="center" prop="accidentName" label="事故名称" show-overflow-tooltip sortable></el-table-column>
				<el-table-column align="center" prop="deptName" label="事故部门" show-overflow-tooltip sortable></el-table-column>
				<el-table-column align="center" prop="occurrencePlace" label="发生地点" show-overflow-tooltip sortable></el-table-column>
				<el-table-column align="center" prop="occurrenceTime" label="发生时间" show-overflow-tooltip sortable
								 :formatter="dateFormat"></el-table-column>
				<el-table-column align="center" prop="accidentCause" label="事故原因" show-overflow-tooltip sortable>
					<template #default="scope">
						<div v-if="scope.row.accidentCause=='1'">人的不安全行为</div>
						<div v-if="scope.row.accidentCause=='2'">物的不安全状态</div>
					</template>
				</el-table-column>
				<el-table-column align="center" prop="createName" label="创建人" show-overflow-tooltip sortable></el-table-column>
				<el-table-column align="center" prop="gmtModitify" label="更新时间" show-overflow-tooltip sortable
								 :formatter="dateFormat"></el-table-column>
				<el-table-column label="操作" width="260" align="center" fixed="right">
					<template #default="scope">
						<!-- <el-button size="small" text disabled>
							<el-icon style="margin-right: 5px"> <Upload /> </el-icon>上报
						</el-button> -->
						<el-button size="small" text type="primary" @click="onEdit('修改', scope.row.id)">
							<el-icon style="margin-right: 5px"> <EditPen /> </el-icon>修改
						</el-button>
						<el-button size="small" text type="primary" @click="onEdit('详情', scope.row.id)">
							<el-icon style="margin-right: 5px"> <View /> </el-icon>详情
						</el-button>
						<el-button size="small" text type="primary" @click="onDelete(scope.row.id)">
							<el-icon style="margin-right: 5px"> <Delete /> </el-icon>删除
						</el-button>
					</template>
				</el-table-column>
			</el-table>
			<div class="pages">
				<el-pagination
					v-if="tableData.length == 0 ? false : true"
					v-model:currentPage="pageIndex"
					v-model:page-size="pageSize"
					:page-sizes="[10, 20, 30]"
					:pager-count="5"
					layout="total, sizes, prev, pager, next, jumper"
					:total="total"
					@size-change="handleSizeChange"
					@current-change="handleCurrentChange"
				/>
			</div>
		</el-card>
		<OpenAdd ref="addRef" @myAdd="onMyAdd" />
		<upData ref="upShow"></upData>
	</div>
</template>

<script lang="ts">
import { reactive, onMounted, ref, defineComponent } from 'vue';
import { ElTable, ElMessage, ElMessageBox } from 'element-plus';
import { Plus, View, Download, Refresh, EditPen, Edit, Delete, Upload } from '@element-plus/icons-vue';
import OpenAdd from '/@/views/accidentManagementSystem/accidentExpress/component/openAdd.vue';
import UpData from '/@/views/contingencyManagement/panManagement/component/upData.vue';
import { accidentManagementSystemApi } from '/@/api/accidentManagementSystem';
export default defineComponent({
	name: 'index',
	components: {
		EditPen,
		Plus,
		Upload,
		Download,
		Refresh,
		Edit,
		Delete,
		UpData,
		OpenAdd,
		View,
	},

	setup() {
		// 列表参数
		const listQuery = reactive({
			pageIndex: 1,
			pageSize: 10,
			searchParams: {
				accidentName: '',
			},
		});
		// 定义表格数据
		const tableData = ref([]);
		// 列表数据请求
		const listApi = async () => {
			let res = await accidentManagementSystemApi().accidentList(listQuery);
			if (res.data.code == 200) {
				tableData.value = res.data.data;
				pageIndex.value = res.data.pageIndex;
				pageSize.value = res.data.pageSize;
				total.value = res.data.total;
			} else {
				ElMessage({
					showClose: true,
					message: res.data.msg,
					type: 'error',
				});
			}
		};
		onMounted(() => {
			listApi();
		});
		// 重置
		const submitReset = () => {
			listQuery.searchParams.accidentName = '';
			listApi();
		};
		// 分页
		const pageIndex = ref();
		const pageSize = ref();
		const total = ref();
		// 分页改变
		const handleSizeChange = (val: number) => {
			// console.log(`${val} items per page`);
			listQuery.pageSize = val;
			listApi();
		};
		// 分页未改变
		const handleCurrentChange = (val: number) => {
			// console.log(`current page: ${val}`);
			listQuery.pageIndex = val;
			listApi();
		};
		const warning = ref(true);
		const danger = ref(true);
		const deletAll = ref();
		const handleSelectionChange = (val: any) => {
			let valId = JSON.parse(JSON.stringify(val));
			let arr = [];
			for (let i = 0; i < valId.length; i++) {
				arr.push(valId[i].id);
			}
			deletAll.value = arr;
			console.log(deletAll.value)
			if (val.length == 1) {
				warning.value = false;
				danger.value = false;
			} else if (val.length == 0) {
				warning.value = true;
				danger.value = true;
			} else {
				warning.value = true;
				danger.value = false;
			}
		};

		// 打开新增弹窗
		const addRef = ref();
		const onOpenAdd = () => {
			addRef.value.openDialog('新建事故快报',false);
		};
		// 新增后刷新
		const onMyAdd = (e: boolean) => {
			if (e) {
				listApi();
			} else {
				listApi();
			}
		};
		// 删除
		const onDelete = (data: any) => {
			ElMessageBox.confirm('确定删除所选项吗?', '提示', {
				confirmButtonText: '确定',
				cancelButtonText: '取消',
				type: 'warning',
			})
				.then(() => {
					accidentManagementSystemApi()
						.accidentDele([data])
						.then((res) => {
							if (res.data.code == 200) {
								ElMessage({
									showClose: true,
									message: res.data.msg,
									type: 'success',
								});
								listApi();
							} else {
								ElMessage({
									showClose: true,
									message: res.data.msg,
									type: 'error',
								});
								listApi();
							}
						});
				})
				.catch(() => {});
		};
		// 多选删除
		const onDeleteAll = () => {
			ElMessageBox.confirm('确定删除所选项吗?', '提示', {
				confirmButtonText: '确定',
				cancelButtonText: '取消',
				type: 'warning',
			})
				.then(() => {
					accidentManagementSystemApi()
						.accidentDele(deletAll.value)
						.then((res) => {
							if (res.data.code == 200) {
								ElMessage({
									showClose: true,
									message: res.data.msg,
									type: 'success',
								});
								listApi();
							} else {
								ElMessage({
									showClose: true,
									message: res.data.msg,
									type: 'error',
								});
								listApi();
							}
						});
				})
				.catch(() => {});
		};
		// 上传
		const upShow = ref();
		const upButton = () => {
			upShow.value.openDialog();
		};

		// 打开修改用户弹窗
		const onEdit = (val: string, row: object) => {
			if (val == '详情') {
				addRef.value.openDialog('查看事故快报',row,true);
			} else {
				addRef.value.openDialog('修改事故快报',row,false);
			}
		};
//格式化表格时间
		const dateFormat = (row,column) => {
			// 获取单元格数据
			let data = row[column.property];
			if(data == null) {
				return null;
			}
			let dt = new Date(data)
			return dt.getFullYear() + '-' + (dt.getMonth() + 1) + '-' + dt.getDate() + ' ' + dt.getHours() + ':' + dt.getMinutes() + ':' + dt.getSeconds()
		};
		return {
			upButton,
			upShow,
			tableData,
			pageIndex,
			pageSize,
			total,
			handleSizeChange,
			handleCurrentChange,
			onEdit,
			onOpenAdd,
			addRef,
			listQuery,
			listApi,
			submitReset,
			warning,
			danger,
			handleSelectionChange,
			onMyAdd,
			onDelete,
			deletAll,
			onDeleteAll,
			dateFormat
		};
	},
});
</script>
<style scoped lang="scss">
.table_Box {
	padding: 20px;
	background-color: #fff;
}
.tableForm {
	margin-top: 10px;
}
/*按钮行*/
.button_Line {
	display: flex;
	flex-direction: row;
	justify-content: space-between;
}
//分页
.pages {
	display: flex;
	justify-content: flex-end;
	margin-top: 15px;
}
::v-deep .el-pagination .el-pager li {
	margin: 0 5px;
	background-color: #f4f4f5;
	color: #606266;
	min-width: 30px;
	border-radius: 2px;
}
::v-deep .el-pagination .el-pager li.is-active {
	background-color: #409eff;
	color: #fff;
}
::v-deep .el-pagination .btn-prev {
	margin: 0 5px;
	background-color: #f4f4f5;
	color: #606266;
	min-width: 30px;
	border-radius: 2px;
}
::v-deep .el-pagination button:disabled {
	color: #c0c4cc;
}
::v-deep .el-pagination .btn-next {
	margin: 0 5px;
	background-color: #f4f4f5;
	color: #606266;
	min-width: 30px;
	border-radius: 2px;
}
</style>
